==> dnv_bladed_models-0.3.32.tar.gz: dnv_bladed_models-0.3.32/src/dnv_bladed_models/pendulum_damper.py <==
# coding: utf-8

from __future__ import annotations
from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra  # noqa: F401

from dnv_bladed_models.angle_vs_stiffness_torque import AngleVsStiffnessTorque

from dnv_bladed_models.damper import Damper

from dnv_bladed_models.pendulum_damper_mounting_position import PendulumDamperMountingPosition

from dnv_bladed_models.velocity_vs_damping_torque import VelocityVsDampingTorque


class PendulumDamper(Damper, ComponentType='PendulumDamper'):
    """PendulumDamper - A pendulum or tuned mass damper, which uses a suspended mass to damp oscillations in a tower.

    Attributes:
        - Length: float => A number representing a length.  The SI units for length are metres.
        - Mass: float => A number representing a mass.  The SI units for mass are kilograms.
        - Inertia: float => A number representing an angular inertia.  The SI units for angular inertia are kilogram radian squareds.
        - Stiffness: float => A number representing a rotational stiffness.  The SI units for rotational stiffness are Newton metres per radian.
        - Damping: float => A number representing a rotational damping term.  The SI units for angular damping are Newton metre per radian.
        - InitialAngle: float => A number representing an angle.  The SI units for angles are radians.
        - ConstantFriction: float => A number representing a torque or moment.  The SI units for moments are Newton-metres.
        - AngleVsStiffnessTorque: List[AngleVsStiffnessTorque] => A look-up table of additional stiffnesses that vary with the pendulum&#39;s position.
        - VelocityVsDampingTorque: List[VelocityVsDampingTorque] => A look-up table of additional damping that vary with the pendulum&#39;s velocity.
        - MountingPosition: PendulumDamperMountingPosition 
        - ComponentType: str [Read-only] => Allows the schema to identify the type of the object.  For this type of object, this must always be set to &#39;PendulumDamper&#39;
    """

    Length: Optional[float] = Field(alias="Length", default=None)
    Mass: Optional[float] = Field(alias="Mass", default=None)
    Inertia: Optional[float] = Field(alias="Inertia", default=None)
    Stiffness: Optional[float] = Field(alias="Stiffness", default=None)
    Damping: Optional[float] = Field(alias="Damping", default=None)
    InitialAngle: Optional[float] = Field(alias="InitialAngle", default=None)
    ConstantFriction: Optional[float] = Field(alias="ConstantFriction", default=None)
    AngleVsStiffnessTorque: Optional[List[AngleVsStiffnessTorque]] = Field(alias="AngleVsStiffnessTorque", default=list())
    VelocityVsDampingTorque: Optional[List[VelocityVsDampingTorque]] = Field(alias="VelocityVsDampingTorque", default=list())
    MountingPosition: Optional[PendulumDamperMountingPosition] = Field(alias="MountingPosition", default=None)
    ComponentType: Optional[str] = Field(alias="ComponentType", default='PendulumDamper', allow_mutation=False)

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass

    @root_validator(pre=True)
    def parsing_ignores_underscore_properties(cls, values: dict[str, any]):
        allowed_vals = {}
        for key, val in values.items():
            if not key.startswith('_'):
                if isinstance(val, dict):
                    allowed_child_vals = {}
                    for child_key, child_val in val.items():
                        if not child_key.startswith('_'):
                            allowed_child_vals[child_key] = child_val
                    allowed_vals[key] = allowed_child_vals
                else:
                    allowed_vals[key] = val
        return allowed_vals

    def to_json(
        self,
        *, 
        include: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        exclude: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        by_alias: bool = True, 
        skip_defaults: Optional[bool] = None, 
        exclude_unset: bool = False, 
        exclude_defaults: bool = False, 
        exclude_none: bool = True, 
        encoder: Optional[Callable[[Any], Any]] = None, 
        models_as_dict: bool = True, 
        **dumps_kwargs: Any) -> str:

        r"""
        Generates a JSON string representation of the model.
        
        Notes
        -----
        `include` and `exclude` arguments as per `dict()`.

        `encoder` is an optional function to supply as `default` to json.dumps(), other arguments as per `json.dumps()`.

        Examples
        --------
        >>> model.to_json()

        Renders the full JSON representation of the model object.
        """

        if dumps_kwargs.get('indent') is None:
            dumps_kwargs.update(indent=2)

        return super().json(
                include=include, 
                exclude=exclude, 
                by_alias=by_alias, 
                skip_defaults=skip_defaults, 
                exclude_unset=exclude_unset, 
                exclude_defaults=exclude_defaults, 
                exclude_none=exclude_none, 
                encoder=encoder, 
                models_as_dict=models_as_dict, 
                **dumps_kwargs)
    
    @classmethod
    def from_file(
        cls: Type['Model'],
        path: Union[str, Path]) -> 'Model':
        
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        PendulumDamper
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = PendulumDamper.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)
    
    @classmethod
    def from_json(
        cls: Type['Model'],
        b: StrBytes) -> 'Model':

        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        PendulumDamper
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = PendulumDamper.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
    
    @classmethod
    def from_dict(
        cls: Type['Model'],
         obj: Any) -> 'Model':

        r"""
        Creates a model object from a dict.

        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        PendulumDamper
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)
    
    def to_file(
        self,
        path: Union[str, Path]):

        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.        

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')

        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())

PendulumDamper.update_forward_refs()

==> dnv_bladed_models-0.3.44.tar.gz: dnv_bladed_models-0.3.44/src/dnv_bladed_models/pendulum_damper.py <==
# coding: utf-8

from __future__ import annotations
from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra  # noqa: F401


from dnv_bladed_models.angle_vs_stiffness_torque import AngleVsStiffnessTorque

from dnv_bladed_models.damper import Damper

from dnv_bladed_models.pendulum_damper_mounting_position import PendulumDamperMountingPosition

from dnv_bladed_models.velocity_vs_damping_torque import VelocityVsDampingTorque


class PendulumDamper(Damper, ComponentType='PendulumDamper'):
    """PendulumDamper - A pendulum or tuned mass damper, which uses a suspended mass to damp oscillations in a tower.
    
    Attributes:
    ----------
    Length : float
        A number representing a length.  The SI units for length are metres.
    Mass : float
        A number representing a mass.  The SI units for mass are kilograms.
    Inertia : float
        A number representing an angular inertia.  The SI units for angular inertia are kilogram radian squareds.
    Stiffness : float
        A number representing a rotational stiffness.  The SI units for rotational stiffness are Newton metres per radian.
    Damping : float
        A number representing a rotational damping term.  The SI units for angular damping are Newton metre per radian.
    InitialAngle : float
        A number representing an angle.  The SI units for angles are radians.
    ConstantFriction : float
        A number representing a torque or moment.  The SI units for moments are Newton-metres.
    AngleVsStiffnessTorque : List[AngleVsStiffnessTorque], default=list()
        A look-up table of additional stiffnesses that vary with the pendulum's position.
    VelocityVsDampingTorque : List[VelocityVsDampingTorque], default=list()
        A look-up table of additional damping that vary with the pendulum's velocity.
    MountingPosition : PendulumDamperMountingPosition
    ComponentType : str, readonly, default='PendulumDamper'
        Allows the schema to identify the type of the object.  For this type of object, this must always be set to 'PendulumDamper'
    
    """

    Length: Optional[float] = Field(alias="Length", default=None)
    Mass: Optional[float] = Field(alias="Mass", default=None)
    Inertia: Optional[float] = Field(alias="Inertia", default=None)
    Stiffness: Optional[float] = Field(alias="Stiffness", default=None)
    Damping: Optional[float] = Field(alias="Damping", default=None)
    InitialAngle: Optional[float] = Field(alias="InitialAngle", default=None)
    ConstantFriction: Optional[float] = Field(alias="ConstantFriction", default=None)
    AngleVsStiffnessTorque: Optional[List[AngleVsStiffnessTorque]] = Field(alias="AngleVsStiffnessTorque", default=list())
    VelocityVsDampingTorque: Optional[List[VelocityVsDampingTorque]] = Field(alias="VelocityVsDampingTorque", default=list())
    MountingPosition: Optional[PendulumDamperMountingPosition] = Field(alias="MountingPosition", default=None)
    ComponentType: Optional[str] = Field(alias="ComponentType", default='PendulumDamper', allow_mutation=False)

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass

    @root_validator(pre=True)
    def _parsing_ignores_underscore_properties(cls, values: dict[str, any]):
        allowed_vals = {}
        for key, val in values.items():
            if not key.startswith('_'):
                if isinstance(val, dict):
                    allowed_child_vals = {}
                    for child_key, child_val in val.items():
                        if not child_key.startswith('_'):
                            allowed_child_vals[child_key] = child_val
                    allowed_vals[key] = allowed_child_vals
                else:
                    allowed_vals[key] = val
        return allowed_vals

    def to_json(
        self,
        *, 
        include: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        exclude: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        by_alias: bool = True, 
        skip_defaults: Optional[bool] = None, 
        exclude_unset: bool = False, 
        exclude_defaults: bool = False, 
        exclude_none: bool = True, 
        encoder: Optional[Callable[[Any], Any]] = None, 
        models_as_dict: bool = True, 
        **dumps_kwargs: Any) -> str:

        r"""
        Generates a JSON string representation of the model.
        
        Notes
        -----
        `include` and `exclude` arguments as per `dict()`.

        `encoder` is an optional function to supply as `default` to json.dumps(), other arguments as per `json.dumps()`.

        Examples
        --------
        >>> model.to_json()

        Renders the full JSON representation of the model object.
        """

        if dumps_kwargs.get('indent') is None:
            dumps_kwargs.update(indent=2)

        return super().json(
                include=include, 
                exclude=exclude, 
                by_alias=by_alias, 
                skip_defaults=skip_defaults, 
                exclude_unset=exclude_unset, 
                exclude_defaults=exclude_defaults, 
                exclude_none=exclude_none, 
                encoder=encoder, 
                models_as_dict=models_as_dict, 
                **dumps_kwargs)
    
    @classmethod
    def from_file(
        cls: Type['Model'],
        path: Union[str, Path]) -> 'Model':
        
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        PendulumDamper
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = PendulumDamper.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)
    
    @classmethod
    def from_json(
        cls: Type['Model'],
        b: StrBytes) -> 'Model':

        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        PendulumDamper
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = PendulumDamper.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
    
    @classmethod
    def from_dict(
        cls: Type['Model'],
         obj: Any) -> 'Model':

        r"""
        Creates a model object from a dict.

        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        PendulumDamper
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)
    
    def to_file(
        self,
        path: Union[str, Path]):

        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.        

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')

        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())

PendulumDamper.update_forward_refs()
